==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QShortcutEvent_shell.h <==
#ifndef QSHORTCUTEVENT_SHELL_H
#define QSHORTCUTEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <qtcore-config.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#if QT_CONFIG(shortcut)
#include <QtGui/qshortcut.h>
#endif //QT_CONFIG(shortcut)
#include <QtJambi/RegistryAPI>


class QShortcutEvent_shell : public QShortcutEvent, public QtJambiShellInterface
{
public:
    QShortcutEvent_shell(const QKeySequence& key0, const QShortcut* shortcut1 = nullptr, bool ambiguous2 = false);
    QShortcutEvent_shell(const QKeySequence& key0, int id1, bool ambiguous2 = false);
    QShortcutEvent_shell(const QShortcutEvent& arg__1);
    ~QShortcutEvent_shell() override;

    QShortcutEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QShortcutEvent_access : public QShortcutEvent
{
    void __qt_assign_cref_QShortcutEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setAmbiguous_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean ambiguous0);

#if QT_CONFIG(shortcut)
    void setKey_cref_QKeySequence(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID key0);
#endif //QT_CONFIG(shortcut)

    void setShortcutId_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint shortcutId0);
};

#endif // QSHORTCUTEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QShortcutEvent_shell.h <==
#ifndef QSHORTCUTEVENT_SHELL_H
#define QSHORTCUTEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <qtcore-config.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#if QT_CONFIG(shortcut)
#include <QtGui/qshortcut.h>
#endif //QT_CONFIG(shortcut)
#include <QtJambi/RegistryAPI>


class QShortcutEvent_shell : public QShortcutEvent, public QtJambiShellInterface
{
public:
    QShortcutEvent_shell(const QKeySequence& key0, const QShortcut* shortcut1 = nullptr, bool ambiguous2 = false);
    QShortcutEvent_shell(const QKeySequence& key0, int id1, bool ambiguous2 = false);
    QShortcutEvent_shell(const QShortcutEvent& arg__1);
    ~QShortcutEvent_shell() override;

    QShortcutEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QShortcutEvent_access : public QShortcutEvent
{
    void __qt_assign_cref_QShortcutEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setAmbiguous_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean ambiguous0);

#if QT_CONFIG(shortcut)
    void setKey_cref_QKeySequence(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID key0);
#endif //QT_CONFIG(shortcut)

    void setShortcutId_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint shortcutId0);
};

#endif // QSHORTCUTEVENT_SHELL_H
